#!/usr/bin/perl
use warnings;
use strict;


# Copyright 2006-8 Simon Andrews
#
#    This file is part of ChIPMonk.
#
#    ChIPMonk is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    ChIPMonk is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with ChIPMonk; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#

if ($ARGV[0]) {
  chdir $ARGV[0] or die "Can't move to $ARGV[0]: $!";
}

if (! -e "Stripped") {
  mkdir "Stripped" or die $!;
}


foreach my $infile (<*.dat>) {

  open (IN,$infile) or die "Can't read $infile: $!";

  while (<IN>) {

    # Find the ID line
    if (/^ID\s*([^\s;]*)/) {
      my $chr = $1;
      # Skip any unmapped contigs
      if ($chr =~ /random/i) {
	skip_to_next();
	next;
      }

      open (OUT,'>>',"Stripped/$chr.dat") or die "Can't write $chr.dat:$!";

      # If we're keeping it we want the next 3 lines
      for (1..3) {
	print OUT scalar <IN>;
      }

      # Then we want to skip to the FH line
      while (<IN>) {
	if (/^FH/) {
	  print OUT;
	  last;
	}
      }

      # Then we want to print everything until the end of the entry
      while (<IN>) {
	if (/^\S\S/) {
	  print OUT;
	}
	last if (/\/\//);
      }

    }


  }

}

sub skip_to_next {
  while (<IN>) {
    last if (/\/\//);
  }
}
